# Changelog

## 1.0.0 (2025-07-21)

Full Changelog: [v0.0.1-alpha.0...v1.0.0](https://github.com/alisytsma/ali-test-mcp/compare/v0.0.1-alpha.0...v1.0.0)

### Chores

* update SDK settings ([66dfaac](https://github.com/alisytsma/ali-test-mcp/commit/66dfaac8f834ac2c4019ea94db8cd15fc3549210))
* update SDK settings ([e0c388c](https://github.com/alisytsma/ali-test-mcp/commit/e0c388c2b79aba1427c64b80bcc803601a61455c))
